@@ -8,7 +8,6 @@ describe 'keystone server running with Apache/WSGI as Service Provider with Shib
       pp= <<-EOS
       include openstack_integration
       include openstack_integration::repos
-      include openstack_integration::apache
       include openstack_integration::mysql
       include openstack_integration::keystone
 
@@ -81,10 +80,6 @@ describe 'keystone server running with Apache/WSGI as Service Provider with Shib
       it { is_expected.to be_listening }
     end
 
-    describe cron do
-      it { is_expected.to have_entry('1 * * * * keystone-manage token_flush >>/var/log/keystone/keystone-tokenflush.log 2>&1').with_user('keystone') }
-    end
-
     shared_examples_for 'keystone user/tenant/service/role/endpoint resources using v3 API' do |auth_creds|
       it 'should find beaker user' do
         shell("openstack #{auth_creds} --os-auth-url http://127.0.0.1:5000/v3 --os-identity-api-version 3 user list") do |r|
