@@ -76,10 +76,6 @@ describe 'keystone server running with Apache/WSGI with resources' do
       it { is_expected.to be_listening }
     end
 
-    describe cron do
-      it { is_expected.to have_entry('1 * * * * keystone-manage token_flush >>/var/log/keystone/keystone-tokenflush.log 2>&1').with_user('keystone') }
-    end
-
     shared_examples_for 'keystone user/tenant/service/role/endpoint resources using v3 API' do |auth_creds|
       it 'should find beaker user' do
         shell("openstack #{auth_creds} --os-auth-url http://127.0.0.1:5000/v3 --os-identity-api-version 3 user list") do |r|
@@ -348,17 +344,8 @@ EOC
           it_behaves_like 'a_valid_configuration', <<-EOC
 
 [ldap]
-use_pool=False
-pool_retry_delay=0.1
 url=ldap://foo
-auth_pool_size=100
-auth_pool_connection_lifetime=60
 user=cn=foo,dc=example,dc=com
-pool_connection_timeout=-1
-use_auth_pool=False
-pool_connection_lifetime=600
-pool_size=10
-pool_retry_max=3
 EOC
         end
 
@@ -366,17 +353,8 @@ EOC
           it_behaves_like 'a_valid_configuration', <<-EOC
 
 [ldap]
-pool_retry_delay=0.1
 url=ldap://bar
 user=cn=bar,dc=test,dc=com
-use_pool=False
-pool_retry_max=3
-pool_size=10
-auth_pool_size=100
-auth_pool_connection_lifetime=60
-use_auth_pool=False
-pool_connection_lifetime=600
-pool_connection_timeout=-1
 EOC
         end
       end
